from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from django.contrib.auth.models import User, Group
from django.utils.translation import gettext_lazy

from django.conf import settings

def custom_context(request):
    return {
        # 登录背景图片
        'LOGIN_BG_IMAGE': settings.SOHO_LOGIN_BG_IMAGE,
        # 站点标题
        'site_header': settings.SOHO_SITE_HEADER,
        'app_list': [
                {      'name': '认证和授权',
            'app_label': 'auth',
            'app_url': '/admin/auth/',
            'has_module_perms': True,
            'models': [
            {
                'model': 'django.contrib.auth.models.User',
                'name': '用户',
                'object_name': 'User',
                'perms':
                {
                    'add': False,
                    'change': False,
                    'delete': False,
                    'view': True
                },
                'admin_url': '/admin/auth/user/',
                'add_url': None,
                'view_only': True
            },
            {
                'model': 'django.contrib.auth.models.Group',
                'name': '组',
                'object_name': 'Group',
                'perms':
                {
                    'add': True,
                    'change': True,
                    'delete': True,
                    'view': True
                },
                'admin_url': '/admin/auth/group/',
                'add_url': '/admin/auth/group/add/',
                'view_only': False
                }]
            }
        ]
    }
    
    

class MyAdminSite(admin.AdminSite):

    # URL for the "View site" link at the top of each admin page.
    site_url = "/"

    enable_nav_sidebar = True

    # 登录页&首页的标题
    site_header = '登录页&首页的标题'
    # 浏览器的标题
    site_title = '浏览器的标题'
    # 正文的标题
    index_title = '正文的标题'
    
    
    # def each_context(self, request):
    #     """
    #     Return a dictionary of variables to put in the template context for
    #     *every* page in the admin site.

    #     For sites running on a subpath, use the SCRIPT_NAME value if site_url
    #     hasn't been customized.
    #     """
    #     script_name = request.META["SCRIPT_NAME"]
    #     site_url = (
    #         script_name if self.site_url == "/" and script_name else self.site_url
    #     )
    #     return {
    #         "site_title": self.site_title,
    #         "site_header": self.site_header,
    #         "site_url": site_url,
    #         "has_permission": self.has_permission(request),
    #         "available_apps": self.get_app_list(request),
    #         "is_popup": False,
    #         "is_nav_sidebar_enabled": self.enable_nav_sidebar,
    #         "log_entries": self.get_log_entries(request),
    #     }
        
    # from django.template import RequestContext
    # from project.context_processors import custom_context
    # custom_context = custom_context(RequestContext(request))
    # context['app_list'] = custom_context['app_list']
    
adminsite = MyAdminSite()


# 注册用户模型
adminsite.register(User, UserAdmin)

# 注册组模型
class GroupAdmin(admin.ModelAdmin):
    filter_horizontal = ['permissions']

adminsite.register(Group, GroupAdmin)


from django.db import models

class AdminMenus(models.Model):
    
    name = models.CharField(max_length=100, verbose_name='菜单名称' )
    url = models.URLField(verbose_name='菜单链接')
    icon = models.CharField(max_length=100, verbose_name='菜单图标icon')
    parent_id = models.ForeignKey('self', on_delete=models.CASCADE, null=True, blank=True, verbose_name='父级菜单')
    sort = models.IntegerField(verbose_name='排序')
    is_show = models.BooleanField(verbose_name='是否显示')
    
    def __str__(self):
        return self.name


    class Meta:
        verbose_name = 'System菜单设置'
        verbose_name_plural = 'System菜单设置'
        ordering = ['sort']



# Generated by Django 5.1.2 on 2024-12-06 08:40

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='AdminMenus',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('url', models.URLField()),
                ('icon', models.CharField(max_length=100)),
                ('sort', models.IntegerField()),
                ('is_show', models.BooleanField()),
                ('parent_id', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='django_sohoui.adminmenus')),
            ],
        ),
    ]



from django.contrib import admin
from .adminsite import adminsite   
from .models import AdminMenus

class AdminMenusAdmin(admin.ModelAdmin):
    list_display = ('name', 'url', 'icon', 'parent_id', 'sort', 'is_show')
    list_filter = ('parent_id', 'is_show')
    search_fields = ('name', 'url')
    ordering = ('sort',)

adminsite.register(AdminMenus, AdminMenusAdmin)